# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.2.0~0fd7b7f',
    built_at='2024-01-02 07:46:47Z',
    sha='0fd7b7f97f993e4e0f3ca92869a3c07f2286d95c',
    branch='HEAD',
    tag='v4.2.0',
)
